% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plots-RNA_halflife_comparison.R
\name{BridgeRResultChecker}
\alias{BridgeRResultChecker}
\title{BRIC-seq result checker}
\usage{
BridgeRResultChecker(inputFile, group = c("Control", "Knockdown"),
  hour = c(0, 1, 2, 4, 8, 12), inforColumn = 4, save = T,
  outputPrefix = "BridgeR_9")
}
\arguments{
\item{inputFile}{The vector of tab-delimited matrix file.}

\item{group}{The vector of group names.}

\item{hour}{The vector of time course about BRIC-seq experiment.}

\item{inforColumn}{The number of information columns.}

\item{save}{Whether to save the output fig file.}

\item{outputPrefix}{The prefix for the name of the output.}
}
\value{
list object about ggplot2 fig data.
}
\description{
\code{BridgeRResultChecker} returns several BRIC-seq result information.
This function is used for checking the distribution of genome-wide RNA half-lives.
}
\examples{
library(data.table)
normalized_table <- data.table(gr_id = c(8, 9, 14),
                               symbol = c("AAAS", "AACS", "AADAT"),
                               accession_id = c("NM_015665", "NM_023928", "NM_182662"),
                               locus = c("chr12", "chr12", "chr4"),
                               CTRL_1_0h = c(1.00, 1.00, 1.00),
                               CTRL_1_1h = c(1.00, 0.86, 0.96),
                               CTRL_1_2h = c(1.00, 0.96, 0.88),
                               CTRL_1_4h = c(1.00, 0.74, 0.85),
                               CTRL_1_8h = c(1.00, 0.86, 0.68),
                               CTRL_1_12h = c(1.01, 0.65, 0.60),
                               gr_id = c(8, 9, 14),
                               symbol = c("AAAS", "AACS", "AADAT"),
                               accession_id = c("NM_015665", "NM_023928", "NM_182662"),
                               locus = c("chr12", "chr12", "chr4"),
                               KD_1_0h = c(1.00, 1.00, 1.00),
                               KD_1_1h = c(1.01, 0.73, 0.71),
                               KD_1_2h = c(1.01, 0.77, 0.69),
                               KD_1_4h = c(1.01, 0.72, 0.67),
                               KD_1_8h = c(1.01, 0.64, 0.38),
                               KD_1_12h = c(1.00, 0.89, 0.63))
group <- c("Control", "Knockdown")
hour <- c(0, 1, 2, 4, 8, 12)
halflife_table <- BridgeRHalfLifeCalcR2Select(normalized_table,
                                              group = group,
                                              hour = hour,
                                              save = FALSE)
pvalue_table <- BridgeRPvalueEvaluation(halflife_table,
                                        group = group,
                                        hour = hour,
                                        save = FALSE)
result_fig <- BridgeRResultChecker(pvalue_table,
                                   save = FALSE)

}

